@@ -140,8 +140,7 @@ start_embedded(DocRoot, SL, GL, Id) when is_list(DocRoot),is_list(SL),is_list(GL
     GC = setup_gconf(GL, yaws_config:make_default_gconf(false, Id)),
     SC = setup_sconf(DocRoot, #sconf{}, SL),
     yaws_config:add_yaws_soap_srv(GC),
-    SCs = yaws_config:add_yaws_auth([SC]),
-    yaws_api:setconf(GC, [SCs]).
+    yaws_api:setconf(GC, [SC]).
 
 add_server(DocRoot, SL) when is_list(DocRoot),is_list(SL) ->
     SC = setup_sconf(DocRoot, #sconf{}, SL),
@@ -278,12 +277,15 @@ setup_sconf(DocRoot, D, SL) ->
            revproxy = lkup(revproxy, SL, 
                            D#sconf.revproxy),
            soptions = lkup(soptions, SL,
-                           D#sconf.soptions)}.
+                           D#sconf.soptions),
+	   stats = lkup(soptions, SL, D#sconf.stats)}.
 
 set_sc_flags([{access_log, Bool}|T], Flags) ->
     set_sc_flags(T, flag(Flags, ?SC_ACCESS_LOG, Bool));
 set_sc_flags([{add_port, Bool}|T], Flags) ->
     set_sc_flags(T, flag(Flags, ?SC_ADD_PORT, Bool));
+set_sc_flags([{statistics, Bool}|T], Flags) ->
+    set_sc_flags(T, flag(Flags, ?SC_STATISTICS, Bool));
 set_sc_flags([{tilde_expand, Bool}|T], Flags) ->
     set_sc_flags(T, flag(Flags, ?SC_TILDE_EXPAND, Bool));
 set_sc_flags([{dir_listings, Bool}|T], Flags) ->
@@ -1739,10 +1741,12 @@ gen_tcp_send(S, Data) ->
               _SSL ->
                   ssl:send(S, Data)
           end,
+    Size = iolist_size(Data),
     case ?gc_has_debug((get(gc))) of
         false ->
             case Res of
                 ok ->
+		    yaws_stats:sent(Size),
                     ok;
                 _Err ->
                     exit(normal)   %% keep quiet
@@ -1750,6 +1754,7 @@ gen_tcp_send(S, Data) ->
         true ->
             case Res of
                 ok ->
+		    yaws_stats:sent(Size),
                     ?Debug("Sent ~p~n", [yaws_debug:nobin(Data)]),
                     ok;
                 Err ->
@@ -1785,11 +1790,17 @@ http_get_headers(CliSock, SSL) ->
         GC#gconf.trace == false ->
             Res;
         is_tuple(Res) ->
-            {Request, Headers} = Res,
-            ReqStr = yaws_api:reformat_request(Request),
+            {RoR, Headers} = Res,
+            {RoRStr, From} = case element(1, RoR) of
+                                 http_request ->
+                                     {yaws_api:reformat_request(RoR),
+                                      from_client};
+                                 http_response ->
+                                     {yaws_api:reformat_response(RoR),
+                                      from_server}
+                             end,
             HStr = headers_to_str(Headers),
-            yaws_log:trace_traffic(from_client, 
-                                   ?F("~n~s~n~s~n",[ReqStr, HStr])),
+            yaws_log:trace_traffic(From, ?F("~n~s~n~s~n",[RoRStr, HStr])),
             Res;
         Res == closed ->
             yaws_log:trace_traffic(from_client, "closed\n"),
