@@ -351,7 +351,7 @@ do_header(Head) ->
         {value, {_,"form-data"++Line}} ->
             Parameters = parse_arg_line(Line),
             {value, {_,Name}} = lists:keysearch(name, 1, Parameters),
-            {mkkey(Name), Parameters};
+            {Name, Parameters};
         _ ->
             {Header}
     end.
@@ -408,7 +408,7 @@ do_parse_spec(<<$%, Hi:8, Lo:8, Tail/binary>>, Spec, Last, Cur, State)
     do_parse_spec(Tail, Spec, Last, [ Hex | Cur],  State);
                
 do_parse_spec(<<$&, Tail/binary>>, Spec, _Last , Cur,  key) ->
-    [{mkkey_reverse(Cur), undefined} |
+    [{lists:reverse(Cur), undefined} |
      do_parse_spec(Tail, Spec, nokey, [], key)];  %% cont keymode
 
 do_parse_spec(<<$&, Tail/binary>>, Spec, Last, Cur, value) ->
@@ -420,7 +420,7 @@ do_parse_spec(<<$+, Tail/binary>>, Spec, Last, Cur,  State) ->
     do_parse_spec(Tail, Spec, Last, [$\s|Cur], State);
 
 do_parse_spec(<<$=, Tail/binary>>, Spec, _Last, Cur, key) ->
-    do_parse_spec(Tail, Spec, mkkey_reverse(Cur), [], value); %% change mode
+    do_parse_spec(Tail, Spec, lists:reverse(Cur), [], value); %% change mode
 
 do_parse_spec(<<$%, $u, A:8, B:8,C:8,D:8, Tail/binary>>, 
 	       Spec, Last, Cur, State) ->
@@ -431,7 +431,7 @@ do_parse_spec(<<$%, $u, A:8, B:8,C:8,D:8, Tail/binary>>,
 do_parse_spec(<<H:8, Tail/binary>>, Spec, Last, Cur, State) ->
     do_parse_spec(Tail, Spec, Last, [H|Cur], State);
 do_parse_spec(<<>>, _Spec, nokey, Cur, _State) ->
-    [{mkkey_reverse(Cur), undefined}];
+    [{lists:reverse(Cur), undefined}];
 do_parse_spec(<<>>, Spec, Last, Cur, _State) ->
     [S|_Ss] = tail_spec(Spec),
     [{Last, coerce_type(S, Cur)}];
@@ -463,19 +463,6 @@ coerce_type(ip, _Str) ->
 coerce_type(binary, Str) ->
     list_to_binary(lists:reverse(Str)).
 
-mkkey_reverse(S) ->
-    mkkey(lists:reverse(S)).
-mkkey(S) ->
-    GC=get(gc),
-    if
-        ?gc_has_backwards_compat_parse(GC) ->
-            list_to_atom(S);
-        true ->
-            S
-    end.
-
-
-
 
 code_to_phrase(100) -> "Continue";
 code_to_phrase(101) -> "Switching Protocols ";
@@ -1022,14 +1009,16 @@ reformat_header(H) ->
 
 
 
+reformat_request(#http_request{method = bad_request}) ->
+    ["Bad request"];
 reformat_request(Req) ->
     Path = case Req#http_request.path of
-	       {abs_path, AbsPath} ->
-		   AbsPath;
-	       {absoluteURI, _Scheme, _Host0, _Port, RawPath} ->
-		   RawPath
-	   end,
-    {Maj,Min} = Req#http_request.version,
+               {abs_path, AbsPath} ->
+                   AbsPath;
+               {absoluteURI, _Scheme, _Host0, _Port, RawPath} ->
+                   RawPath
+           end,
+    {Maj, Min} = Req#http_request.version,
     [yaws:to_list(Req#http_request.method), " ", Path," HTTP/",
      integer_to_list(Maj),".", integer_to_list(Min)].
 
@@ -1780,14 +1769,16 @@ setconf(GC0, Groups0, CheckCertsChanged) ->
         true ->
             ok
     end,
-    {GC, Groups} = yaws_config:verify_upgrade_args(GC0, Groups0),
+    
+    {GC, Groups1} = yaws_config:verify_upgrade_args(GC0, Groups0),
+    Groups2 = lists:map(fun(X) -> yaws_config:add_yaws_auth(X) end, Groups1),
     {ok, OLDGC, OldGroups} = yaws_api:getconf(),
     case {yaws_config:can_hard_gc(GC, OLDGC),
-          yaws_config:can_soft_setconf(GC, Groups, OLDGC, OldGroups)} of
+          yaws_config:can_soft_setconf(GC, Groups2, OLDGC, OldGroups)} of
         {true, true} ->
-            yaws_config:soft_setconf(GC, Groups, OLDGC, OldGroups);
+            yaws_config:soft_setconf(GC, Groups2, OLDGC, OldGroups);
         {true, false} when OLDGC == undefined -> 
-            yaws_config:hard_setconf(GC, Groups);
+            yaws_config:hard_setconf(GC, Groups2);
         _ ->
             {error, need_restart}
     end.
