@@ -57,7 +57,7 @@ handle_clidata(Arg, Worker) ->
         {partial, Data} ->
             send_clidata(Worker, Data),
             {get_more, cgicont, {cgistate, Worker}};
-        Data when binary(Data) ->
+        Data when is_binary(Data) ->
             send_clidata(Worker, Data),
             end_of_clidata(Arg, Worker)
     end.
@@ -147,11 +147,11 @@ checkdef(L) ->
 
 deep_drop_prefix([], L) ->
     L;
-deep_drop_prefix([X|Xs], [X|Ys]) when integer(X) ->
+deep_drop_prefix([X|Xs], [X|Ys]) when is_integer(X) ->
     deep_drop_prefix(Xs, Ys);
-deep_drop_prefix([X|Xs], Ys) when list(X) ->
+deep_drop_prefix([X|Xs], Ys) when is_list(X) ->
     deep_drop_prefix(X++Xs, Ys);
-deep_drop_prefix(Xs, [Y|Ys]) when list(Y) ->
+deep_drop_prefix(Xs, [Y|Ys]) when is_list(Y) ->
     deep_drop_prefix(Xs, Y++Ys);
 deep_drop_prefix(_, _) ->
     false.
@@ -244,6 +244,14 @@ cgi_env(Arg, Scriptfilename, Pathinfo, ExtraEnv, SC) ->
             AuthEnv = []
     end,
 
+    Extra_CGI_Vars = lists:flatmap(fun({Dir, Vars}) ->
+					   case lists:prefix(Dir, Scriptname) of
+					       true -> Vars;
+					       false -> []
+					   end
+				   end,
+				   SC#sconf.extra_cgi_vars),
+
     %%todo - review. should AuthEnv entries be overridable by ExtraEnv or not?
     %% we should define policy here rather than let through dupes.
 
@@ -251,7 +259,7 @@ cgi_env(Arg, Scriptfilename, Pathinfo, ExtraEnv, SC) ->
         HttpsEnv ++
         AuthEnv ++
         lists:filter(
-          fun({K, L}) when list(L) -> 
+          fun({K, L}) when is_list(L) -> 
                   case lists:keysearch(K, 1, ExtraEnv) of
                       false ->
                           true;
@@ -324,7 +332,8 @@ cgi_env(Arg, Scriptfilename, Pathinfo, ExtraEnv, SC) ->
             {"HTTP_COOKIE", flatten_val(make_cookie_val(H#headers.cookie))}
            ]++lists:map(fun({http_header,_,Var,_,Val})->{tohttp(Var),Val} end,
                         H#headers.other)
-          )).
+          )) ++
+	Extra_CGI_Vars.
 
 tohttp(X) ->
     "HTTP_"++lists:map(fun tohttp_c/1, yaws:to_list(X)).
@@ -358,7 +367,7 @@ make_cookie_val([C|CS]) ->
 %% Seems not to be necessary, but open_port documentation says that
 %% value has to be a string.
 
-flatten_val(L) when list(L) ->
+flatten_val(L) when is_list(L) ->
     lists:flatten(L);
 flatten_val(X) ->
     X.
