@@ -109,17 +109,23 @@ parse_request(Args) -> % {{{
      end.  % }}}
 
 handle_payload(Args, Handler, Type) -> % {{{
-    Payload = binary_to_list(Args#arg.clidata),
-%    ?Debug("rpc plaintext call ~p ~n", [Payload]),
-
     RpcType = recognize_rpc_type(Args),
-
     % haXe parameters are URL encoded
-    DecodedStr = case RpcType of
-                     haxe -> yaws_api:url_decode(Payload);
-             json -> yaws_api:url_decode(Payload);
-                     _ -> Payload
-                 end,
+    {Payload,DecodedStr} = 
+	case RpcType of
+	    T when T==haxe; T==json ->
+		PL = binary_to_list(Args#arg.clidata),
+		%%    ?Debug("rpc plaintext call ~p ~n", [PL]),
+		{PL, yaws_api:url_decode(PL)};
+	    soap_dime ->
+		[{_,_,_,Req}|As]=yaws_dime:decode(Args#arg.clidata),
+		{Args#arg.clidata,
+		 {binary_to_list(Req),As}};
+	    _ ->
+		PL = binary_to_list(Args#arg.clidata),
+		{PL, PL}
+		%%    ?Debug("rpc plaintext call ~p ~n", [PL])
+	end,
     case decode_handler_payload(RpcType, DecodedStr) of
         {ok, DecodedPayload, ID} ->
             % ?Debug("client2erl decoded call ~p ~n", [DecodedPayload]),
@@ -133,8 +139,12 @@ handle_payload(Args, Handler, Type) -> % {{{
 %%% "X-Haxe-Remoting" HTTP header, then the "SOAPAction" header,
 %%% and if those are absent we assume the request is JSON.
 recognize_rpc_type(Args) ->
-    OtherHeaders = ((Args#arg.headers)#headers.other),
-    recognize_rpc_hdr([{X,Y,yaws:to_lower(Z),Q,W} || {X,Y,Z,Q,W} <- OtherHeaders]).
+    case (Args#arg.headers)#headers.content_type of
+	"application/dime" -> soap_dime;
+	_ ->
+	    OtherHeaders = ((Args#arg.headers)#headers.other),
+	    recognize_rpc_hdr([{X,Y,yaws:to_lower(Z),Q,W} || {X,Y,Z,Q,W} <- OtherHeaders])
+    end.
 
 recognize_rpc_hdr([{_,_,"x-haxe-remoting",_,_}|_]) -> haxe;
 recognize_rpc_hdr([{_,_,"soapaction",_,_}|_])      -> soap;
@@ -227,11 +237,11 @@ handle_cookie(Cookie, CookieName, SessionValue, NewSessionValue, M, F) ->
 %%% Make it possible for callback module to set Cookie Expire string!
 get_expire(M, F) -> 
     case catch M:F(cookie_expire) of
-        Expire when list(Expire) -> Expire;
+        Expire when is_list(Expire) -> Expire;
         _                        -> false
     end.
 
-callback_fun(M, F, Args, Payload, SessionValue, soap) ->
+callback_fun(M, F, Args, Payload, SessionValue, RpcType) when RpcType==soap; RpcType==soap_dime ->
     fun() -> yaws_soap_srv:handler(Args, {M,F}, Payload, SessionValue) end;
 callback_fun(M, F, Args, Payload, SessionValue, _RpcType) ->
     fun() -> M:F(Args#arg.state, Payload, SessionValue) end.
@@ -245,6 +255,9 @@ encode_send(Args, StatusCode, [Payload], AddOn, ID, RpcType) ->  % {{{
 encode_send(Args, StatusCode, Payload, AddOn, ID, RpcType) -> % {{{
 %    ?Debug("rpc response ~p ~n", [Payload]),
     case encode_handler_payload(Payload, ID, RpcType) of
+        {ok, EncodedPayload, NewRpcType} ->
+%        ?Debug("rpc encoded response ~p ~n", [EncodedPayload]),
+            send(Args, StatusCode, EncodedPayload, AddOn, NewRpcType);
         {ok, EncodedPayload} ->
 %        ?Debug("rpc encoded response ~p ~n", [EncodedPayload]),
             send(Args, StatusCode, EncodedPayload, AddOn, RpcType);
@@ -272,6 +285,23 @@ send(_Args, StatusCode, Payload, AddOnData, RpcType) ->
 content_hdr(json, Payload) -> {content, "application/json", Payload};
 content_hdr(_, Payload)    -> {content, "text/xml", Payload}.  % FIXME  would like to add charset info here !!
 
+encode_handler_payload({Xml,[]}, _ID, soap_dime) ->   % {{{
+    {ok, Xml, soap};
+
+encode_handler_payload({Xml,As}, _ID, soap_dime) ->   % {{{
+	EncodedPayload = yaws_dime:encode(Xml, As),
+    {ok, EncodedPayload};
+
+encode_handler_payload(Xml, _ID, soap_dime) ->   % {{{
+    {ok, Xml, soap};
+
+encode_handler_payload({Xml,[]}, _ID, soap) ->   % {{{
+    {ok, Xml};
+
+encode_handler_payload({Xml,As}, _ID, soap) ->   % {{{
+	EncodedPayload = yaws_dime:encode(Xml, As),
+    {ok, EncodedPayload, soap_dime};
+
 encode_handler_payload(Xml, _ID, soap) ->   % {{{
     {ok, Xml};
 
@@ -313,6 +343,8 @@ decode_handler_payload(haxe, [$_, $_, $x, $= | HaxeStr]) ->
 decode_handler_payload(haxe, _HaxeStr) ->
     {error, missing_haxe_prefix};
 
+decode_handler_payload(soap_dime, Payload) ->
+    {ok, Payload, undefined};
 decode_handler_payload(soap, Payload) ->
     {ok, Payload, undefined}.
 
