@@ -138,5 +138,5 @@ find_runmod([]) ->
 
 %%----------------------------------------------------------------------
 %%----------------------------------------------------------------------
-l2a(L) when list(L) -> list_to_atom(L);
-l2a(A) when atom(A) -> A.
+l2a(L) when is_list(L) -> list_to_atom(L);
+l2a(A) when is_atom(A) -> A.
